@@ -169,7 +169,7 @@ class NetrisGatewayConnector:
 
     async def get_user_camera_group(self, token: str, id: str, group_name: str) -> list[CameraGroupWithId]:
         answer = await self._connector.post(
-            "/camera_group/get", {"id": id, "group_name": group_name},
+            "/user/camera_group/get", {"id": id, "group_name": group_name},
             headers=self._construct_bearer_auth_header(token))
         return [dict_to_dataclass(camera_group, CameraGroupWithId) for camera_group in answer]
 
